#!/bin/bash

: ${DIALOG=dialog}

CDTITLE="SOLARSPEED.NET Presents - Network Reconfigure"
TITLE="Network Setup Utility"

dmesg -n 1

IPADDRESS=`cat /etc/sysconfig/network-scripts/ifcfg-eth0  | /bin/grep IPADDR | /bin/cut -f2 -d=`
IPV6ADDRESS=`cat /etc/sysconfig/network-scripts/ifcfg-eth0  | /bin/grep IPV6ADDR | /bin/cut -f2 -d=`
NETMASK=`cat /etc/sysconfig/network-scripts/ifcfg-eth0  | /bin/grep NETMASK | /bin/cut -f2 -d=`
DEFAULTGW=`cat /etc/sysconfig/network | /bin/grep GATEWAY | /bin/cut -f2 -d=`
IPV6DEFAULTGW=`cat /etc/sysconfig/network | /bin/grep IPV6_DEFAULTGW | /bin/cut -f2 -d=`
DNS=`cat /etc/sysconfig/network-scripts/ifcfg-eth0|grep DNS1|cut -d = -f2`

if [ -f /etc/sysconfig/network-scripts/ifcfg-br0 ]; then
  IPADDRESS=`cat /etc/sysconfig/network-scripts/ifcfg-br0  | /bin/grep IPADDR | /bin/cut -f2 -d=`
  IPV6ADDRESS=`cat /etc/sysconfig/network-scripts/ifcfg-br0  | /bin/grep IPV6ADDR | /bin/cut -f2 -d=`
  NETMASK=`cat /etc/sysconfig/network-scripts/ifcfg-br0  | /bin/grep NETMASK | /bin/cut -f2 -d=`
  DEFAULTGW=`cat /etc/sysconfig/network | /bin/grep GATEWAY | /bin/cut -f2 -d=`
  IPV6DEFAULTGW=`cat /etc/sysconfig/network | /bin/grep IPV6_DEFAULTGW | /bin/cut -f2 -d=`
  DNS=`cat /etc/sysconfig/network-scripts/ifcfg-br0|grep DNS1|cut -d = -f2`
fi

function GetIP() {
MSG="Please Enter your IPv4 IP Address\n\n"
exec 3>&1
IPADDRESS="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $IPADDRESS 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetNM() {
MSG="Please Enter your IPv4 Netmask\n\n"
exec 3>&1
NETMASK="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $NETMASK 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetDNS() {
MSG="Please Enter your DNS Server IP Address\n\n"
exec 3>&1
DNS="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $DNS 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetGW() {
MSG="Please Enter your IPv4 Default Gateway\n\n"
exec 3>&1
DEFAULTGW="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $DEFAULTGW 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function IPv6GetIP() {
MSG="Please Enter your IPv6 IP Address\n\n"
exec 3>&1
IPV6ADDRESS="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $IPV6ADDRESS 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function IPv6GetGW() {
MSG="Please Enter your IPv6 Default Gateway\n\n"
exec 3>&1
IPV6DEFAULTGW="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $IPV6DEFAULTGW 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function Confirm() {
MSG="
Please Confirm your Network Settings\n\n
IPv4 IP Address : $IPADDRESS\n
IPv4 Netmask    : $NETMASK\n
IPv4 Gateway    : $DEFAULTGW\n\n
DNS  IP Address : $DNS\n\n
IPv6 IP Address : $IPV6ADDRESS\n
IPv6 Gateway    : $IPV6DEFAULTGW\n
\n\n
Accept?"
$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE" \
  --yesno "$MSG" 0 0
NO=$?
}

NO=1
V4=0
V6=0

GetIP
GetNM
GetGW
GetDNS
IPv6GetIP
IPv6GetGW
Confirm
if [ "$IPADDRESS" == "" ]; then NO=1; fi
if [ "$NETMASK" == "" ]; then NO=1; fi
if [ "$DEFAULTGW" == "" ]; then NO=1; fi
if [ "$DNS" == "" ]; then NO=1; fi
if [ "$IPV6ADDRESS" == "" ]; then NO=2; fi
if [ "$IPV6DEFAULTGW" == "" ]; then NO=2; fi

if [ "$IPADDRESS" != "" ] && [ "$NETMASK" != "" ] && [ "$DEFAULTGW" != "" ] && [ "$DNS" != "" ];then
  # We do have IPv4 
  NO=0
  V4=1

fi

if [ "$IPV6ADDRESS" != "" ] && [ "$IPV6DEFAULTGW" != "" ] && [ "$DNS" != "" ];then
  # We do have IPv6 
  NO=0
  V6=1
fi

if [ "$NO" == "0" ]; then

  # Configure up the init scripts for eth0 properly.
  /bin/echo "DEVICE=eth0" > /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "BOOTPROTO=none" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "ONBOOT=yes" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "BRIDGE=br0" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "NM_CONTROLLED=no" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "USERCTL=no" >> /etc/sysconfig/network-scripts/ifcfg-eth0

  echo "Applying new network configuration ... "

  if [ "$V4" == "1" ] && [ "$V6" == "1" ]; then
    echo "/usr/sausalito/sbin/nethelper.pl --device=br0 --ipv4ip=$IPADDRESS --ipv4nm=$NETMASK --ipv4gw=$DEFAULTGW --ipv6=$IPV6ADDRESS --ipv6gw=$IPV6DEFAULTGW --dns=$DNS"
    /usr/sausalito/sbin/nethelper.pl --device=br0 --ipv4ip=$IPADDRESS --ipv4nm=$NETMASK --ipv4gw=$DEFAULTGW --ipv6=$IPV6ADDRESS --ipv6gw=$IPV6DEFAULTGW --dns=$DNS
  fi
  if [ "$V4" == "1" ] && [ "$V6" == "0" ]; then
    echo "/usr/sausalito/sbin/nethelper.pl --device=br0 --ipv4ip=$IPADDRESS --ipv4nm=$NETMASK --ipv4gw=$DEFAULTGW --dns=$DNS"
    /usr/sausalito/sbin/nethelper.pl --device=br0 --ipv4ip=$IPADDRESS --ipv4nm=$NETMASK --ipv4gw=$DEFAULTGW --dns=$DNS
  fi
  if [ "$V4" == "0" ] && [ "$V6" == "1" ]; then
    echo "/usr/sausalito/sbin/nethelper.pl --device=br0 --ipv6=$IPV6ADDRESS --ipv6gw=$IPV6DEFAULTGW --dns=$DNS"
    /usr/sausalito/sbin/nethelper.pl --device=br0 --ipv6=$IPV6ADDRESS --ipv6gw=$IPV6DEFAULTGW --dns=$DNS
  fi  

  echo "Restarting Daemons ... "
  services="network cced.init httpd admserv sendmail firewalld"
  for service in $services; do
    /sbin/chkconfig $service on > /dev/null 2>&1 || :
    /sbin/service $service restart > /dev/null 2>&1 || :
  done

fi

# Configure /etc/issue:
/bin/echo "Aventurin{e} 6109R (\n)" > /etc/issue
/bin/echo "vzkernel: \r" >> /etc/issue
if [ "$V4" == "1" ];then
        /bin/echo "IPv4 Address: $IPADDRESS" >> /etc/issue
fi   
if [ "$V6" == "1" ];then
        /bin/echo "IPv6 Address: $IPV6ADDRESS" >> /etc/issue
fi

# Clean up /root/.bashrc:
/bin/echo "# Source global definitions" > /root/.bashrc
/bin/echo "if [ -f /etc/bashrc ]; then" >> /root/.bashrc
/bin/echo "        . /etc/bashrc" >> /root/.bashrc
/bin/echo "fi" >> /root/.bashrc

# 
# Copyright (c) 2018 Michael Stauber, SOLARSPEED.NET
# All Rights Reserved.
# 
# 1. Redistributions of source code must retain the above copyright 
#  notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#  notice, this list of conditions and the following disclaimer in 
#  the documentation and/or other materials provided with the 
#  distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its 
#  contributors may be used to endorse or promote products derived 
#  from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# 
# You acknowledge that this software is not designed or intended for 
# use in the design, construction, operation or maintenance of any 
# nuclear facility.
#
